@@ -66,7 +66,20 @@ JSON::Dumper::Compact - JSON processing with L<Data::Dumper::Compact> aesthetics
 JSON::Dumper::Compact is a subclass of L<Data::Dumper::Compact> that turns
 arrayrefs and hashrefs intead into JSON.
 
-Blessed references without a C<TO_JSON> method are rendered as:
+Deep data structures are rendered highly compactly:
+
+  [
+    "1556933590.65383", "Fri May  3 18:33:10 2019", 26794, "INFO", 3,
+    [ "SRV:8FB66F32" ], [ [
+        "/opt/voice-srvc-native/bin/async-srvc-att-gateway-poller", 33,
+        "NERV::Voice::SRV::Native::AsyncSRVATTGatewayPoller::main",
+    ] ],
+    "batch_nena_messages returned", "OK", 6, { "FILENAME": "lqxw020323" },
+    1556933584, "lqxw020323",
+  ]
+
+To ease debugging, blessed references without a C<TO_JSON> method are
+rendered as an object with a single two-element arrayref value:
 
   { "__bless__": [
     "The::Class",
@@ -95,9 +108,14 @@ set to be able to reliably reparse what we can currently format - notably
 setting C<relaxed> to allow for trailing commas and using
 C<filter_json_single_key_object> to re-inflate blessed objects.
 
-Note that using this method on untrusted data is a security risk. Don't use
+Note that using this method on untrusted data is a security risk. While
+C<encode>/C<dump> should be usable for JSON formatting, in general,
+C<decode> fully rehydrates for debugging purposes and as such can e.g.
+cause DESTROY methods to be called unexpectedly, which can allow a
+malicious user to do things to your perl5 VM. Rather than using
 debugging specific code on untrusted data, use L<JSON::MaybeXS> or
-L<Mojo::JSON> directly.
+L<Mojo::JSON> directly (if the C<encode> output doesn't parse correctly
+via other libraries, please report that as a bug)..
 
 DO NOT USE THIS METHOD ON UNTRUSTED DATA IT WAS NOT DESIGNED TO BE SECURE.
 
